@@ -297,8 +297,7 @@ func UpgradeableCheck(kubeClient client.Client,
 	newSecrets []types.NamespacedName,
 	rootSecret types.NamespacedName) *configv1.ClusterOperatorStatusCondition {
 	upgradeableCondition := &configv1.ClusterOperatorStatusCondition{
-		Status: configv1.ConditionTrue,
-		Type:   configv1.OperatorUpgradeable,
+		Type: configv1.OperatorUpgradeable,
 	}
 
 	if mode == operatorv1.CloudCredentialsModeManual {
@@ -333,7 +332,7 @@ func UpgradeableCheck(kubeClient client.Client,
 			upgradeableCondition.Status = configv1.ConditionFalse
 			upgradeableCondition.Reason = constants.MissingSecretsForUpgradeReason
 			upgradeableCondition.Message = fmt.Sprintf(
-				"Cannot upgrade manual mode cluster to %s due to missing secret(s): %v Please see Manually Creating IAM documentation for the cluster's platform.",
+				"Cannot upgrade manual mode cluster to %s due to missing secret(s): %v Please see Manualy Creating IAM documentation for the cluster's platform.",
 				toRelease,
 				missingSecrets)
 			return upgradeableCondition
@@ -363,5 +362,6 @@ func UpgradeableCheck(kubeClient client.Client,
 		}
 	}
 
-	return upgradeableCondition
+	// Only return non-default conditions as the status controller will set defaults
+	return nil
 }
